package com.chelvc.cloud.vehicle.client;
import com.chelvc.cloud.vehicle.client.dto.UserReceiveAddressDTO;
import com.chelvc.cloud.vehicle.client.param.UserReceiveAddressModifyParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 用户常用地址业务接口
 *
 * @author liude
 * @data 2024/04/29
 */
@FeignClient("vehicle")
public interface UserReceiveAddressClient {

    /**
     * 新增用户常用地址
     *
     * @param param 新增参数
     * @return 主键
     */
    @PostMapping("/userReceiveAddress/add")
    Long add(@SpringQueryMap UserReceiveAddressModifyParam param);

    /**
     * 修改用户常用地址
     *
     * @param id    主键
     * @param param 修改参数
     */
    @PutMapping("/userReceiveAddress/update")
    Long update(@RequestParam("id") Long id, @SpringQueryMap UserReceiveAddressModifyParam param);

    /**
     * 查询用户常用地址列表
     *
     * @return 用户常用地址信息
     */
    @GetMapping("/userReceiveAddress/list")
    List<UserReceiveAddressDTO> getList();


    /**
     * 删除用户常用地址
     *
     * @param id    主键
     */
    @PutMapping("/userReceiveAddress/delete")
    void delete(@RequestParam("id") Long id);

    /**
     * 用户常用地址详情
     *
     * @param id    用户常用地址主键
     */
    @GetMapping("/userReceiveAddress/queryById")
    UserReceiveAddressDTO queryById(@RequestParam("id") Long id) ;
}
