package com.chelvc.cloud.vehicle.client.param;

import java.io.Serializable;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;

import com.chelvc.framework.common.model.Region;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 经纬度查询参数
 *
 * @author Woody
 * @date 2023/5/5
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class LocationQueryParam implements Serializable {
    /**
     * 地区编码
     */
    @NotNull(message = "地区编码不能为空")
    @Min(value = 100000, message = "地区编码不能小于100000")
    @Max(value = 999999, message = "地区编码不能大于999999")
    private Integer region;

    /**
     * 经度
     */
    @NotNull(message = "经度不能为空")
    private Double longitude;

    /**
     * 纬度
     */
    @NotNull(message = "纬度不能为空")
    private Double latitude;

    /**
     * 推荐分类数量
     */
    private Integer catPageSize = 15;

    /**
     * 附近商家条数
     */
    private Integer nearPageSize = 15;

    /**
     * 推荐商家数量
     */
    private Integer recPageSize = 15;

    private Integer code;

    private Integer boundary;


}
