package com.chelvc.cloud.vehicle.server.controller;

import java.util.List;

import com.chelvc.cloud.vehicle.client.dto.FavoriteDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.client.param.FavoritePagingParam;
import com.chelvc.cloud.vehicle.client.param.FavoriteQueryParam;
import com.chelvc.cloud.vehicle.server.service.FavoriteService;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 商品收藏接口
 *
 * @author liude
 * @date 2023/7/18
 */
@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class FavoriteController {

    private final FavoriteService favoriteService;

    /**
     * 收藏商家
     *
     * @param merchantId 商家ID
     * @return 收藏ID
     */
    @PostMapping("/favorite/addMerchantFavorite")
    public Long addMerchantFavorite(@RequestParam("merchantId") Long merchantId, @RequestParam("type") String type) {
        return favoriteService.addMerchantFavorite(merchantId, type);
    }

    /**
     * 取消我的收藏
     *
     * @param id 收藏ID
     */
    @DeleteMapping("/favorite")
    public void deleteMineFavorite(@RequestParam("id") Long id) {
        favoriteService.deleteMineFavorite(id);
    }

    /**
     * 查询收藏列表
     *
     * @param param 查询参数
     * @return 收藏店铺分页信息
     */
    @GetMapping("/favorite/getFavoriteMerchantPaging")
    public Pagination<MerchantDTO> getFavoriteMerchantPaging(FavoritePagingParam param) {
        return favoriteService.getFavoriteMerchantPaging(param);
    }

    /**
     * 查询用户收藏店铺列表
     *
     * @param param 查询参数
     * @return 用户收藏店铺列表
     */
    @GetMapping("/favorite/listFavoriteMerchants")
    public List<FavoriteDTO> listFavoriteMerchants(FavoriteQueryParam param) {
        return favoriteService.listFavoriteMerchants(param);
    }

    /**
     * 查询用户收藏商品列表
     *
     * @return 用户收藏商品列表
     */
    @GetMapping("/favorite/listFavoriteGoods")
    public List<FavoriteDTO> listFavoriteGoods() {
        return favoriteService.listFavoriteGoods();
    }
}
